import { HostHeaderInputConfig, HostHeaderResolvedConfig } from "@aws-sdk/middleware-host-header";
import { AwsAuthInputConfig, AwsAuthResolvedConfig } from "@aws-sdk/middleware-signing";
import { UserAgentInputConfig, UserAgentResolvedConfig } from "@aws-sdk/middleware-user-agent";
import { Credentials as __Credentials } from "@aws-sdk/types";
import { RegionInputConfig, RegionResolvedConfig } from "@smithy/config-resolver";
import { EndpointInputConfig, EndpointResolvedConfig } from "@smithy/middleware-endpoint";
import { RetryInputConfig, RetryResolvedConfig } from "@smithy/middleware-retry";
import { HttpHandler as __HttpHandler } from "@smithy/protocol-http";
import { Client as __Client, DefaultsMode as __DefaultsMode, SmithyConfiguration as __SmithyConfiguration, SmithyResolvedConfiguration as __SmithyResolvedConfiguration } from "@smithy/smithy-client";
import { BodyLengthCalculator as __BodyLengthCalculator, ChecksumConstructor as __ChecksumConstructor, Decoder as __Decoder, Encoder as __Encoder, HashConstructor as __HashConstructor, HttpHandlerOptions as __HttpHandlerOptions, Logger as __Logger, Provider as __Provider, Provider, StreamCollector as __StreamCollector, UrlParser as __UrlParser, UserAgent as __UserAgent } from "@smithy/types";
import { CreateChannelCommandInput, CreateChannelCommandOutput } from "./commands/CreateChannelCommand";
import { CreateChannelGroupCommandInput, CreateChannelGroupCommandOutput } from "./commands/CreateChannelGroupCommand";
import { CreateOriginEndpointCommandInput, CreateOriginEndpointCommandOutput } from "./commands/CreateOriginEndpointCommand";
import { DeleteChannelCommandInput, DeleteChannelCommandOutput } from "./commands/DeleteChannelCommand";
import { DeleteChannelGroupCommandInput, DeleteChannelGroupCommandOutput } from "./commands/DeleteChannelGroupCommand";
import { DeleteChannelPolicyCommandInput, DeleteChannelPolicyCommandOutput } from "./commands/DeleteChannelPolicyCommand";
import { DeleteOriginEndpointCommandInput, DeleteOriginEndpointCommandOutput } from "./commands/DeleteOriginEndpointCommand";
import { DeleteOriginEndpointPolicyCommandInput, DeleteOriginEndpointPolicyCommandOutput } from "./commands/DeleteOriginEndpointPolicyCommand";
import { GetChannelCommandInput, GetChannelCommandOutput } from "./commands/GetChannelCommand";
import { GetChannelGroupCommandInput, GetChannelGroupCommandOutput } from "./commands/GetChannelGroupCommand";
import { GetChannelPolicyCommandInput, GetChannelPolicyCommandOutput } from "./commands/GetChannelPolicyCommand";
import { GetOriginEndpointCommandInput, GetOriginEndpointCommandOutput } from "./commands/GetOriginEndpointCommand";
import { GetOriginEndpointPolicyCommandInput, GetOriginEndpointPolicyCommandOutput } from "./commands/GetOriginEndpointPolicyCommand";
import { ListChannelGroupsCommandInput, ListChannelGroupsCommandOutput } from "./commands/ListChannelGroupsCommand";
import { ListChannelsCommandInput, ListChannelsCommandOutput } from "./commands/ListChannelsCommand";
import { ListOriginEndpointsCommandInput, ListOriginEndpointsCommandOutput } from "./commands/ListOriginEndpointsCommand";
import { ListTagsForResourceCommandInput, ListTagsForResourceCommandOutput } from "./commands/ListTagsForResourceCommand";
import { PutChannelPolicyCommandInput, PutChannelPolicyCommandOutput } from "./commands/PutChannelPolicyCommand";
import { PutOriginEndpointPolicyCommandInput, PutOriginEndpointPolicyCommandOutput } from "./commands/PutOriginEndpointPolicyCommand";
import { TagResourceCommandInput, TagResourceCommandOutput } from "./commands/TagResourceCommand";
import { UntagResourceCommandInput, UntagResourceCommandOutput } from "./commands/UntagResourceCommand";
import { UpdateChannelCommandInput, UpdateChannelCommandOutput } from "./commands/UpdateChannelCommand";
import { UpdateChannelGroupCommandInput, UpdateChannelGroupCommandOutput } from "./commands/UpdateChannelGroupCommand";
import { UpdateOriginEndpointCommandInput, UpdateOriginEndpointCommandOutput } from "./commands/UpdateOriginEndpointCommand";
import { ClientInputEndpointParameters, ClientResolvedEndpointParameters, EndpointParameters } from "./endpoint/EndpointParameters";
export { __Client };
/**
 * @public
 */
export type ServiceInputTypes = CreateChannelCommandInput | CreateChannelGroupCommandInput | CreateOriginEndpointCommandInput | DeleteChannelCommandInput | DeleteChannelGroupCommandInput | DeleteChannelPolicyCommandInput | DeleteOriginEndpointCommandInput | DeleteOriginEndpointPolicyCommandInput | GetChannelCommandInput | GetChannelGroupCommandInput | GetChannelPolicyCommandInput | GetOriginEndpointCommandInput | GetOriginEndpointPolicyCommandInput | ListChannelGroupsCommandInput | ListChannelsCommandInput | ListOriginEndpointsCommandInput | ListTagsForResourceCommandInput | PutChannelPolicyCommandInput | PutOriginEndpointPolicyCommandInput | TagResourceCommandInput | UntagResourceCommandInput | UpdateChannelCommandInput | UpdateChannelGroupCommandInput | UpdateOriginEndpointCommandInput;
/**
 * @public
 */
export type ServiceOutputTypes = CreateChannelCommandOutput | CreateChannelGroupCommandOutput | CreateOriginEndpointCommandOutput | DeleteChannelCommandOutput | DeleteChannelGroupCommandOutput | DeleteChannelPolicyCommandOutput | DeleteOriginEndpointCommandOutput | DeleteOriginEndpointPolicyCommandOutput | GetChannelCommandOutput | GetChannelGroupCommandOutput | GetChannelPolicyCommandOutput | GetOriginEndpointCommandOutput | GetOriginEndpointPolicyCommandOutput | ListChannelGroupsCommandOutput | ListChannelsCommandOutput | ListOriginEndpointsCommandOutput | ListTagsForResourceCommandOutput | PutChannelPolicyCommandOutput | PutOriginEndpointPolicyCommandOutput | TagResourceCommandOutput | UntagResourceCommandOutput | UpdateChannelCommandOutput | UpdateChannelGroupCommandOutput | UpdateOriginEndpointCommandOutput;
/**
 * @public
 */
export interface ClientDefaults extends Partial<__SmithyResolvedConfiguration<__HttpHandlerOptions>> {
    /**
     * The HTTP handler to use. Fetch in browser and Https in Nodejs.
     */
    requestHandler?: __HttpHandler;
    /**
     * A constructor for a class implementing the {@link @smithy/types#ChecksumConstructor} interface
     * that computes the SHA-256 HMAC or checksum of a string or binary buffer.
     * @internal
     */
    sha256?: __ChecksumConstructor | __HashConstructor;
    /**
     * The function that will be used to convert strings into HTTP endpoints.
     * @internal
     */
    urlParser?: __UrlParser;
    /**
     * A function that can calculate the length of a request body.
     * @internal
     */
    bodyLengthChecker?: __BodyLengthCalculator;
    /**
     * A function that converts a stream into an array of bytes.
     * @internal
     */
    streamCollector?: __StreamCollector;
    /**
     * The function that will be used to convert a base64-encoded string to a byte array.
     * @internal
     */
    base64Decoder?: __Decoder;
    /**
     * The function that will be used to convert binary data to a base64-encoded string.
     * @internal
     */
    base64Encoder?: __Encoder;
    /**
     * The function that will be used to convert a UTF8-encoded string to a byte array.
     * @internal
     */
    utf8Decoder?: __Decoder;
    /**
     * The function that will be used to convert binary data to a UTF-8 encoded string.
     * @internal
     */
    utf8Encoder?: __Encoder;
    /**
     * The runtime environment.
     * @internal
     */
    runtime?: string;
    /**
     * Disable dynamically changing the endpoint of the client based on the hostPrefix
     * trait of an operation.
     */
    disableHostPrefix?: boolean;
    /**
     * Unique service identifier.
     * @internal
     */
    serviceId?: string;
    /**
     * Enables IPv6/IPv4 dualstack endpoint.
     */
    useDualstackEndpoint?: boolean | __Provider<boolean>;
    /**
     * Enables FIPS compatible endpoints.
     */
    useFipsEndpoint?: boolean | __Provider<boolean>;
    /**
     * The AWS region to which this client will send requests
     */
    region?: string | __Provider<string>;
    /**
     * Default credentials provider; Not available in browser runtime.
     * @internal
     */
    credentialDefaultProvider?: (input: any) => __Provider<__Credentials>;
    /**
     * The provider populating default tracking information to be sent with `user-agent`, `x-amz-user-agent` header
     * @internal
     */
    defaultUserAgentProvider?: Provider<__UserAgent>;
    /**
     * Value for how many times a request will be made at most in case of retry.
     */
    maxAttempts?: number | __Provider<number>;
    /**
     * Specifies which retry algorithm to use.
     */
    retryMode?: string | __Provider<string>;
    /**
     * Optional logger for logging debug/info/warn/error.
     */
    logger?: __Logger;
    /**
     * The {@link @smithy/smithy-client#DefaultsMode} that will be used to determine how certain default configuration options are resolved in the SDK.
     */
    defaultsMode?: __DefaultsMode | __Provider<__DefaultsMode>;
}
/**
 * @public
 */
export type MediaPackageV2ClientConfigType = Partial<__SmithyConfiguration<__HttpHandlerOptions>> & ClientDefaults & RegionInputConfig & EndpointInputConfig<EndpointParameters> & RetryInputConfig & HostHeaderInputConfig & AwsAuthInputConfig & UserAgentInputConfig & ClientInputEndpointParameters;
/**
 * @public
 *
 *  The configuration interface of MediaPackageV2Client class constructor that set the region, credentials and other options.
 */
export interface MediaPackageV2ClientConfig extends MediaPackageV2ClientConfigType {
}
/**
 * @public
 */
export type MediaPackageV2ClientResolvedConfigType = __SmithyResolvedConfiguration<__HttpHandlerOptions> & Required<ClientDefaults> & RegionResolvedConfig & EndpointResolvedConfig<EndpointParameters> & RetryResolvedConfig & HostHeaderResolvedConfig & AwsAuthResolvedConfig & UserAgentResolvedConfig & ClientResolvedEndpointParameters;
/**
 * @public
 *
 *  The resolved configuration interface of MediaPackageV2Client class. This is resolved and normalized from the {@link MediaPackageV2ClientConfig | constructor configuration interface}.
 */
export interface MediaPackageV2ClientResolvedConfig extends MediaPackageV2ClientResolvedConfigType {
}
/**
 * @public
 * <note>
 *             <p>This guide is intended for creating AWS Elemental MediaPackage resources in MediaPackage Version 2 (v2) starting from May 2023.
 *         To get started with MediaPackage v2, create your MediaPackage resources. There isn't an automated process to
 *         migrate your resources from MediaPackage v1 to MediaPackage v2. </p>
 *             <p>The names of the entities that you use to access this API, like URLs and ARNs, all have the versioning information
 *            added, like "v2", to distinguish from the prior version. If you used MediaPackage prior to this release, you can't use
 *            the MediaPackage v2 CLI or the MediaPackage v2 API to access any MediaPackage v1 resources.</p>
 *             <p>If you created resources in MediaPackage v1, use video on demand (VOD) workflows, and aren't looking to migrate to MediaPackage v2 yet,
 *            see the <a href="https://docs.aws.amazon.com/mediapackage/latest/apireference/what-is.html">MediaPackage v1 Live API Reference</a>.</p>
 *          </note>
 *          <p>This is the AWS Elemental MediaPackage v2 Live REST API Reference. It describes all the MediaPackage API operations for live content in detail, and provides sample requests, responses, and errors for the supported web services protocols.</p>
 *          <p>We assume that you have the IAM permissions that you need to use MediaPackage via the REST API. We also assume that you are familiar with the features and operations of MediaPackage, as described in the AWS Elemental MediaPackage User Guide.</p>
 */
export declare class MediaPackageV2Client extends __Client<__HttpHandlerOptions, ServiceInputTypes, ServiceOutputTypes, MediaPackageV2ClientResolvedConfig> {
    /**
     * The resolved configuration of MediaPackageV2Client class. This is resolved and normalized from the {@link MediaPackageV2ClientConfig | constructor configuration interface}.
     */
    readonly config: MediaPackageV2ClientResolvedConfig;
    constructor(configuration: MediaPackageV2ClientConfig);
    /**
     * Destroy underlying resources, like sockets. It's usually not necessary to do this.
     * However in Node.js, it's best to explicitly shut down the client's agent when it is no longer needed.
     * Otherwise, sockets might stay open for quite a long time before the server terminates them.
     */
    destroy(): void;
}
